==> campsite-2.6.1.tar.gz: campsite/implementation/management/priv/lang/sh/templates.php <==
<?php 
regGS("Template ID:", "");
regGS("Template ID", "");
regGS("Template $1 no longer exists!", "");
regGS("New template $1 created", "");
regGS("If the file you specified is a text file, you can convert its character set using the dropdown below.", "");
regGS("Directory $1 was deleted", "");
regGS("Directory $1 created.", "");
regGS("You must select a file to upload.", "");
regGS("You can only replace a file with a file of the same type.  The original file is of type \"$1\", and the file you uploaded was of type \"$2\".", "");
regGS("Unable to save the file '$1' to the path '$2'.", "");
regGS("Replace file:", "");
regGS("Replace", "");
regGS("File \"$1\" uploaded.", "");
regGS("File \"$1\" replaced.", "");
regGS("The folder name can't be '..' or '.'", "");
regGS("The template '$1' was saved successfully.", "Šablon '$1' je uspešno snimljen.");
regGS("The template $1 is in use and can not be deleted.", "Šablon $1 je u upotrebi i ne može biti obrisan.");
regGS("Create new folder", "Napravi novi folder");
regGS("Upload template", "Aplouduj šablon");
regGS("You do not have the right to create new folders.", "Nemate pravo da pravite nove foldere");
regGS("A file or folder having the name $1 already exists", "Fajl ili folder sa imenom $1 već postoji");
regGS("You do not have the right to delete templates.", "Nemate pravo da brišete šablone");
regGS("Are you sure you want to delete the folder $1 from $2?", "Da li ste sigurni da želite da obrišete folder $1 iz $2?");
regGS("Are you sure you want to delete the template $1 from folder $2?", "Da li ste sigurni da želite da obrišete šablon $1 iz foldera $2?");
regGS("Template $1 was deleted", "Šablon $1 je obrisan");
regGS("Delete folder", "Obriši folder");
regGS("Folders", "Folderi");
regGS("No folders.", "Nema foldera.");
regGS("Files", "Fajlovi");
regGS("No templates.", "Nema šablona.");
regGS("File", "Fajl");
regGS("Create new template", "Napravi novi šablon");
regGS("Duplicate template", "Dupliraj šablon");
regGS("Edit template", "Uredi šablon");
regGS("The template $1 could not be created.", "Šablon $1 ne može biti napravljen.");
regGS("Template $1 was changed", "Šablon $1 je promenjen");
regGS("Template $1 was duplicated into $2", "Šablon $1 je dupliran u $2");
regGS("Template charset", "Kodni raspored šablona");
regGS("Select a language/character set", "Izaberi jezik/kodni raspored");
regGS("All languages", "Svi jezici");
regGS("You do not have the right to modify templates.", "Nemate pravo da menjate šablone.");
regGS("Invalid template file $1", "Pogrešno ime šablona $1");
regGS("You do not have the right to create folders.", "Nemate pravo da pravite foldere.");
regGS("You do not have the right to upload templates.", "Nemate pravo da aploudujete šablone.");
regGS("You do not have the right to create templates.", "Nemate pravo da pravite šablone.");
regGS("Duplicate file", "Dupliraj fajl");
regGS("Delete file", "Obriši fajl");
regGS("Please check if the user '$1' has permission to write in this directory.", "Proverite da li korisnik '$1' ima ovlašćenja da upisuje u ovoaj direktorijum.");
regGS("The folder has been deleted.", "Folder je izbrisan");
regGS("The template has been deleted.", "Šablon je izbrisan");
regGS("The template could not be deleted.", "Šablon ne može biti izbrisan");
regGS("Save", "Snimi");
?>

==> campsite-2.6.6.tar.gz: campsite/implementation/management/priv/lang/sh/templates.php <==
<?php 
regGS("Unable to create folder.", "Nije moguće kreirati folder");
regGS("Unable to $1 template.", "Nije moguće $1 šablon");
regGS("File cannot be read.", "Fajl $1 nije čitljiv");
regGS("Template ID:", "ID šablona:");
regGS("Template ID", "ID šablona");
regGS("Template $1 no longer exists!", "Šablon $1 više ne postoji!");
regGS("New template $1 created", "Kreiran je novi šablon $1");
regGS("If the file you specified is a text file, you can convert its character set using the dropdown below.", "Ako je fajl koji ste uneli tekstualni fajl, možete promeniti njegov karakter set pomoću padajućeg menija");
regGS("Directory $1 was deleted", "Direktorijum $1 je obrisan");
regGS("Directory $1 created.", "Direktorijum $1 je kreiran");
regGS("You must select a file to upload.", "Moratre izabrati fajl koji želite da aploudujete");
regGS("You can only replace a file with a file of the same type.  The original file is of type \"$1\", and the file you uploaded was of type \"$2\".", "Fajl možete zameniti jedino drugim fajlom istog tipa. Originalni fajl je tipa '$1', a fajl koji ste aploudovali je tipa '$2'");
regGS("Unable to save the file '$1' to the path '$2'.", "Nije moguće snimiti fajl '$1' na putanju '$2'");
regGS("Replace file:", "Zameni fajl");
regGS("Replace", "Zameni");
regGS("File \"$1\" uploaded.", "Fajl '$1' je aploudovan");
regGS("File \"$1\" replaced.", "Fajl '$1' je zamenjen");
regGS("The folder name can't be '..' or '.'", "Ime foldera ne može biti '..' ili '.'");
regGS("The template '$1' was saved successfully.", "Šablon '$1' je uspešno snimljen.");
regGS("The template $1 is in use and can not be deleted.", "Šablon $1 je u upotrebi i ne može biti obrisan.");
regGS("Create new folder", "Napravi novi folder");
regGS("Upload template", "Aplouduj šablon");
regGS("You do not have the right to create new folders.", "Nemate pravo da pravite nove foldere");
regGS("A file or folder having the name $1 already exists", "Fajl ili folder sa imenom $1 već postoji");
regGS("You do not have the right to delete templates.", "Nemate pravo da brišete šablone");
regGS("Are you sure you want to delete the folder $1 from $2?", "Da li ste sigurni da želite da obrišete folder $1 iz $2?");
regGS("Are you sure you want to delete the template $1 from folder $2?", "Da li ste sigurni da želite da obrišete šablon $1 iz foldera $2?");
regGS("Template $1 was deleted", "Šablon $1 je obrisan");
regGS("Delete folder", "Obriši folder");
regGS("Folders", "Folderi");
regGS("No folders.", "Nema foldera.");
regGS("Files", "Fajlovi");
regGS("No templates.", "Nema šablona.");
regGS("File", "Fajl");
regGS("Create new template", "Napravi novi šablon");
regGS("Duplicate template", "Dupliraj šablon");
regGS("Edit template", "Uredi šablon");
regGS("The template $1 could not be created.", "Šablon $1 ne može biti napravljen.");
regGS("Template $1 was changed", "Šablon $1 je promenjen");
regGS("Template $1 was duplicated into $2", "Šablon $1 je dupliran u $2");
regGS("Template charset", "Kodni raspored šablona");
regGS("Select a language/character set", "Izaberi jezik/kodni raspored");
regGS("All languages", "Svi jezici");
regGS("You do not have the right to modify templates.", "Nemate pravo da menjate šablone.");
regGS("Invalid template file $1", "Pogrešno ime šablona $1");
regGS("You do not have the right to create folders.", "Nemate pravo da pravite foldere.");
regGS("You do not have the right to upload templates.", "Nemate pravo da aploudujete šablone.");
regGS("You do not have the right to create templates.", "Nemate pravo da pravite šablone.");
regGS("Duplicate file", "Dupliraj fajl");
regGS("Delete file", "Obriši fajl");
regGS("Please check if the user '$1' has permission to write in this directory.", "Proverite da li korisnik '$1' ima ovlašćenja da upisuje u ovoaj direktorijum.");
regGS("The folder has been deleted.", "Folder je izbrisan");
regGS("The template has been deleted.", "Šablon je izbrisan");
regGS("The template could not be deleted.", "Šablon ne može biti izbrisan");
regGS("Save", "Snimi");
?>
